@@ -1,7 +1,7 @@
 /*
  *  sounddlg.h  -  sound file selection and configuration dialog and widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2005-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2025 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -15,7 +15,7 @@
 class QPushButton;
 class QShowEvent;
 class QResizeEvent;
-class AudioPlayer;
+class AudioPlugin;
 class GroupBox;
 class PushButton;
 class CheckBox;
@@ -40,6 +40,7 @@ public:
     bool           file(QUrl&, bool showErrorMessage = true) const;
     void           getVolume(float& volume, float& fadeVolume, int& fadeSeconds) const;
     int            repeatPause() const;   // -1 if none, else seconds between repeats
+                             //cppcheck-suppress[returnByReference]  QString implicitly shared
     QString        defaultDir() const    { return mDefaultDir; }
     bool           validate(bool showErrorMessage) const;
 
@@ -77,7 +78,7 @@ private:
     Slider*              mFadeSlider {nullptr};
     mutable QUrl         mUrl;
     mutable QString      mValidatedFile;
-    AudioPlayer*         mPlayer {nullptr};
+    AudioPlugin*         mPlayer {nullptr};
     bool                 mReadOnly {false};
     bool                 mEmptyFileAllowed {false};
 };
